@@ -1,7 +1,7 @@
 package Text::ANSITable;
 
 our $DATE = '2015-10-21'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -1673,7 +1673,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.44 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-10-21.
+This document describes version 0.45 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-10-21.
 
 =head1 SYNOPSIS
 
@@ -1720,7 +1720,10 @@ ASCII characters if terminal does not support them.
 =item * Unicode and wide character support
 
 Border styles using Unicode characters (double lines, bold/heavy lines, brick
-style, etc). Columns containing wide characters stay aligned.
+style, etc). Columns containing wide characters stay aligned. (Note: support for
+wide characters requires L<Text::ANSI::WideUtil> which is currently set as an
+optional prereq, so you'll need to install it explicitly or set your CPAN client
+to install 'recommends' prereq).
 
 =back
 
@@ -2220,9 +2223,9 @@ instead of C<ta_mbwrap()>, and so on).
 
 =head2 wide => BOOL
 
-Whether to include wide-character support. The default is to check for the
-existence of L<Text::ANSI::WideUtil> (an optional prereq). You can explicitly
-enable or disable wide-character support here.
+Whether to support wide characters. The default is to check for the existence of
+L<Text::ANSI::WideUtil> (an optional prereq). You can explicitly enable or
+disable wide-character support here.
 
 =head2 border_style => HASH
 
